==> kubernetes-model-extensions-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressLoadBalancerStatusFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressLoadBalancerStatusFluent<A extends IngressLoadBalancerStatusFluent<A>> extends Fluent<A>{
  public A addToIngress(Integer index,IngressLoadBalancerIngress item);
  public A setToIngress(Integer index,IngressLoadBalancerIngress item);
  public A addToIngress(io.fabric8.kubernetes.api.model.extensions.IngressLoadBalancerIngress... items);
  public A addAllToIngress(Collection<IngressLoadBalancerIngress> items);
  public A removeFromIngress(io.fabric8.kubernetes.api.model.extensions.IngressLoadBalancerIngress... items);
  public A removeAllFromIngress(Collection<IngressLoadBalancerIngress> items);
  public A removeMatchingFromIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IngressLoadBalancerIngress> getIngress();
  public List<IngressLoadBalancerIngress> buildIngress();
  public IngressLoadBalancerIngress buildIngress(Integer index);
  public IngressLoadBalancerIngress buildFirstIngress();
  public IngressLoadBalancerIngress buildLastIngress();
  public IngressLoadBalancerIngress buildMatchingIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  public Boolean hasMatchingIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  public A withIngress(List<IngressLoadBalancerIngress> ingress);
  public A withIngress(io.fabric8.kubernetes.api.model.extensions.IngressLoadBalancerIngress... ingress);
  public Boolean hasIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> addNewIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> addNewIngressLike(IngressLoadBalancerIngress item);
  public IngressLoadBalancerStatusFluent.IngressNested<A> setNewIngressLike(Integer index,IngressLoadBalancerIngress item);
  public IngressLoadBalancerStatusFluent.IngressNested<A> editIngress(Integer index);
  public IngressLoadBalancerStatusFluent.IngressNested<A> editFirstIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> editLastIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> editMatchingIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface IngressNested<N> extends Nested<N>,IngressLoadBalancerIngressFluent<IngressLoadBalancerStatusFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  
}

==> kubernetes-model-extensions-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/IngressLoadBalancerStatusFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressLoadBalancerStatusFluent<A extends IngressLoadBalancerStatusFluent<A>> extends Fluent<A>{
  public A addToIngress(int index,IngressLoadBalancerIngress item);
  public A setToIngress(int index,IngressLoadBalancerIngress item);
  public A addToIngress(io.fabric8.kubernetes.api.model.extensions.IngressLoadBalancerIngress... items);
  public A addAllToIngress(Collection<IngressLoadBalancerIngress> items);
  public A removeFromIngress(io.fabric8.kubernetes.api.model.extensions.IngressLoadBalancerIngress... items);
  public A removeAllFromIngress(Collection<IngressLoadBalancerIngress> items);
  public A removeMatchingFromIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IngressLoadBalancerIngress> getIngress();
  public List<IngressLoadBalancerIngress> buildIngress();
  public IngressLoadBalancerIngress buildIngress(int index);
  public IngressLoadBalancerIngress buildFirstIngress();
  public IngressLoadBalancerIngress buildLastIngress();
  public IngressLoadBalancerIngress buildMatchingIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  public Boolean hasMatchingIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  public A withIngress(List<IngressLoadBalancerIngress> ingress);
  public A withIngress(io.fabric8.kubernetes.api.model.extensions.IngressLoadBalancerIngress... ingress);
  public Boolean hasIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> addNewIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> addNewIngressLike(IngressLoadBalancerIngress item);
  public IngressLoadBalancerStatusFluent.IngressNested<A> setNewIngressLike(int index,IngressLoadBalancerIngress item);
  public IngressLoadBalancerStatusFluent.IngressNested<A> editIngress(int index);
  public IngressLoadBalancerStatusFluent.IngressNested<A> editFirstIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> editLastIngress();
  public IngressLoadBalancerStatusFluent.IngressNested<A> editMatchingIngress(Predicate<IngressLoadBalancerIngressBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface IngressNested<N> extends Nested<N>,IngressLoadBalancerIngressFluent<IngressLoadBalancerStatusFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  
}
